# Changelog

## 0.5.0 (2025-10-07)

Full Changelog: [v0.4.1...v0.5.0](https://github.com/miruml/python-server-sdk/compare/v0.4.1...v0.5.0)

### Features

* **api:** uat environment ([67e2b55](https://github.com/miruml/python-server-sdk/commit/67e2b5530fadfbd61d67e85d4fc5b4c363558fd9))

## 0.4.1 (2025-10-05)

Full Changelog: [v0.4.1-beta.3...v0.4.1](https://github.com/miruml/python-server-sdk/compare/v0.4.1-beta.3...v0.4.1)

### Documentation

* update docs ([c152552](https://github.com/miruml/python-server-sdk/commit/c15255242bb7a5051d8618682afd0b981fe32396))

## 0.4.1-beta.3 (2025-10-05)

Full Changelog: [v0.4.1-beta.2...v0.4.1-beta.3](https://github.com/miruml/python-server-sdk/compare/v0.4.1-beta.2...v0.4.1-beta.3)

### Bug Fixes

* **api:** expansions to use bracket format ([0344365](https://github.com/miruml/python-server-sdk/commit/03443654ab20a279be8594224358a15b746cfd01))

## 0.4.1-beta.2 (2025-10-05)

Full Changelog: [v0.4.1-beta.1...v0.4.1-beta.2](https://github.com/miruml/python-server-sdk/compare/v0.4.1-beta.1...v0.4.1-beta.2)

### Styles

* alphabetize webhook imports ([944a3ef](https://github.com/miruml/python-server-sdk/commit/944a3ef1b90d1efcff434ad218237107fb216a56))


### Refactors

* webhook payload to be type 'Any' instead of 'string' ([d0f5bdf](https://github.com/miruml/python-server-sdk/commit/d0f5bdf96c37812e15ddba85ce45e898491546ae))

## 0.4.1-beta.1 (2025-10-05)

Full Changelog: [v0.4.1-beta.0...v0.4.1-beta.1](https://github.com/miruml/python-server-sdk/compare/v0.4.1-beta.0...v0.4.1-beta.1)

### Features

* **api:** manual updates ([1f24c3f](https://github.com/miruml/python-server-sdk/commit/1f24c3f238e13344e158a909a8444fe6a02534ec))
* **api:** manual updates ([616466d](https://github.com/miruml/python-server-sdk/commit/616466d196871cb65ad48ecccf292be3596043b1))

## 0.4.1-beta.0 (2025-10-05)

Full Changelog: [v0.4.0...v0.4.1-beta.0](https://github.com/miruml/python-server-sdk/compare/v0.4.0...v0.4.1-beta.0)

### Refactors

* **api:** rename miru-server to miru ([163c465](https://github.com/miruml/python-server-sdk/commit/163c4659c64f6b954d9b91e7b340554f0919efa6))
* **api:** revert package name to miru_server_sdk ([0c8b7d7](https://github.com/miruml/python-server-sdk/commit/0c8b7d74ae67df4005fc069c4575ffae78b975c6))

## 0.4.0 (2025-09-23)

Full Changelog: [v0.0.1...v0.4.0](https://github.com/miruml/python-server-sdk/compare/v0.0.1...v0.4.0)

### Chores

* update SDK settings ([e7bd9a6](https://github.com/miruml/python-server-sdk/commit/e7bd9a6b432ceeb9e9746577c0588bc3d8d6d81c))
* update SDK settings ([e6ec403](https://github.com/miruml/python-server-sdk/commit/e6ec4031305e950d8f61d18a55344de0e36f752b))
